Learn R Programming

ToxicR (version 22.12.1.0.7)

create_continuous_prior: create_continuous_prior Given priorlist, a model, and a distribution. Create a prior for a given analysis.

Description

create_continuous_prior Given priorlist, a model, and a distribution. Create a prior for a given analysis.

Usage

create_continuous_prior(prior_list, model, distribution, deg = 2)

Value

new BMDprior list. This object is essentially a prior list constructed by create_prior_lists with a model type and variance type.

Arguments

prior_list

First Prior

model

Model to be used one of "hill","exp-3","exp-5","power","polynomial"

distribution

- Normal "normal", Normal non-constant variance "normal-ncv", or log-normal "lognormal"

deg

- For polynomial models only, the degree of the polynomial.

Examples

Run this code
plist<- create_prior_list(normprior(0,0.1,-100,100), # a
                          normprior(0,1,  -1e2,1e2),     # b
                          lnormprior(1,0.2,0,18),  #k
                          normprior(0,1,-18,18))
 
 power_normal <- create_continuous_prior(plist,"power","normal") 

Run the code above in your browser using DataLab