Learn R Programming

ToxicR (version 22.12.1.0.7)

dichotomousDR: 733 unique dose-response datasets

Description

A dataset containing 733 dichotomous dose-response studies that were involved in regulatory risk assessment.

Usage

dichotomousDR

Arguments

Format

A data frame with 2727 rows and 11 variables:

ID

-The study ID in the database.

chemical

-Name of the Chemical in the study.

data.source

-Source of the risk assessment data.

CASRN

-Chemical's CASRN

dose

-Dose spacing of the study using the original study.

r.dose

-Doses of the experiment relative to 1 being the maximum dose tested.

n

-Number of animals on test.

obs

-Number of adverse events.

organ

-Organ impacted.

effect

-Type of adverse effect.

study.source

-Publication related to the experiment.

More information at: tools:::Rd_expr_doi("10.1111/risa.13218")