Learn R Programming

ToxicR (version 22.12.1.0.7)

ntp_dunn: ntp_dunn Dunn's test

Description

ntp_dunn Dunn's test

Usage

ntp_dunn(formula, data, dose_name = "dose")

Value

The results of a Dunn's test for each level in \(dose_name\).

Arguments

formula

An equation of the form \(Y \sim X.\) Here the variable \(Y\) is the response of interest, and \(X\) represents discrete experimental conditions. For example, if weight is the dependent variable, and you are interested in looking at the trend across sex one would have 'weight ~ sex'.

data

A data frame with column names in the formula.

dose_name

The name of the variable containing the doses in the data frame \(data\). It is expected multiple doses for each of the experimental conditions \(X\).

Examples

Run this code

a = ntp_dunn(response ~ sex + response_type,data=ntp_599_hemotology,
                                             dose_name="concentration")
summary(a)

Run the code above in your browser using DataLab