Learn R Programming

ToxicR (version 22.12.1.0.7)

ntp_jonckeere: ntp_jonckeere Jonckherre's test for significant differences from background dose

Description

ntp_jonckeere Jonckherre's test for significant differences from background dose

Usage

ntp_jonckeere(formula, data, dose_name = "dose", pair = "Williams")

Value

The results of a global test for difference from background.

Arguments

formula

An equation of the form \(Y \sim X.\) Here the variable \(Y\) is the response of interest, and \(X\) represents discrete experimental conditions. For example, if weight is the dependent variable, and you are interested in looking at the trend across sex one would have 'weight ~ sex'.

data

A data frame with column names in the formula.

dose_name

The name of the variable containing the doses in the data frame \(data\). It is expected multiple doses for each of the experimental conditions \(X\).

pair

The type of test used for pairwise comparison. It can either be "Williams" or "Shirley"

Examples

Run this code

ntp_jonckeere(response ~ sex + response_type,data=ntp_599_hemotology,dose_name="concentration")

Run the code above in your browser using DataLab