A dataset containing 733 dichotomous dose-response studies that were involved in regulatory risk assessment.
dichotomousDRA data frame with 2727 rows and 11 variables:
-The study ID in the database.
-Name of the Chemical in the study.
-Source of the risk assessment data.
-Chemical's CASRN
-Dose spacing of the study using the original study.
-Doses of the experiment relative to 1 being the maximum dose tested.
-Number of animals on test.
-Number of adverse events.
-Organ impacted.
-Type of adverse effect.
-Publication related to the experiment.
More information at: tools:::Rd_expr_doi("10.1111/risa.13218")