The results of a global test for difference from background.
Arguments
formula
An equation of the form \(Y \sim X.\) Here the variable
\(Y\) is the response of interest, and \(X\) represents discrete experimental
conditions. For example, if weight is the dependent variable, and you are
interested in looking at the trend across sex one would have 'weight ~ sex'.
data
A data frame with column names in the formula.
dose_name
The name of the variable containing the doses in the data frame \(data\).
It is expected multiple doses for each of the experimental conditions \(X\).
pair
The type of test used for pairwise comparison. It can either be
"Williams" or "Shirley"