ntp_polyk: Poly-k test
This function implements the NTP's polyK trend test.
Description
Poly-k test
This function implements the NTP's polyK trend test.
Usage
ntp_polyk(dose, tumor, daysOnStudy)
Value
The results of a Williams trend test for each level in dose_name.
More information on this procedure at: tools:::Rd_expr_doi("10.2307/2531856") and tools:::Rd_expr_doi("10.2307/2532200")
This procedure returns a vector of three p-values for the poly-1.5, poly-3, and poly-6 test
respectively.
Arguments
dose
An equation of the form \(Y \sim X.\) Here the variable
\(Y\) is the response of interest, and \(X\) represents discrete experimental
conditions. For example, if weight is the dependent variable, and you are
interested in looking at the trend across sex one would have 'weight ~ sex'.
tumor
A data frame with column names in the formula.
daysOnStudy
The name of the variable containing the doses in the data frame \(data\).
It is expected multiple doses for each of the experimental conditions \(X\).