The results of a Williams trend test for each level in \(dose_name\).
For more information on the Williams trend test: tools:::Rd_expr_doi("10.2307/2528930")
#'
X: this represents all the class objects on the right hand side of \( Y \sim X\) above.
dose: the dose groups relative to control.
willStat: Value of the Shirley test statistic.
mult_comp_signif: Test's significance as 0, 1, or 2 which is not-significant,
significant at the 0.05
mult_comp_test: The type of test, i.e. "William"
Arguments
formula
An equation of the form \(Y \sim X.\) Here the variable
\(Y\) is the response of interest, and \(X\) represents discrete experimental
conditions. For example, if weight is the dependent variable, and you are
interested in looking at the trend across sex one would have 'weight ~ sex'.
data
A data frame with column names in the formula.
dose_name
The name of the variable containing the doses in the data frame \(data\).
It is expected multiple doses for each of the experimental conditions \(X\).